summaryrefslogtreecommitdiffstats
path: root/src/kscopepixmaps.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kscopepixmaps.h')
-rw-r--r--src/kscopepixmaps.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/kscopepixmaps.h b/src/kscopepixmaps.h
index 2577ef6..db27712 100644
--- a/src/kscopepixmaps.h
+++ b/src/kscopepixmaps.h
@@ -38,7 +38,7 @@
* Handles all pixmaps required by KScope.
* There are two types of pixmaps: embedded, i.e., pixmaps whose pixels are
* given by static two-dimensional arrays, and loadable, which are retrieved
* through the KIconLoader mechanism.
* The application uses a single global instance of this class.
* @author Elad Lahav
*/
@@ -69,7 +69,7 @@ private:
TQPixmap** m_pPixArray;
/** An icon loader used to retrieve pixmaps through the KDE mechanism. */
- KIconLoader m_loader;
+ TDEIconLoader m_loader;
};
extern KScopePixmaps& Pixmaps();
@@ -38,7 +38,7 @@
* There are two types of pixmaps: embedded, i.e., pixmaps whose pixels are
* given by static two-dimensional arrays, and loadable, which are retrieved
- * through the KIconLoader mechanism.
+ * through the TDEIconLoader mechanism.
* The application uses a single global instance of this class.
* @author Elad Lahav